==> jc-1.4.0.tar.gz: java/nio/channels/spi/SelectorProvider.h <==
// public abstract class java.nio.channels.spi.SelectorProvider

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7a7cc23db1b62549 java_nio_channels_spi_SelectorProvider

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_spi_SelectorProvider_H_
#define _JC_java_nio_channels_spi_SelectorProvider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_DatagramChannel$object;
struct _jc_java_nio_channels_Pipe$object;
struct _jc_java_nio_channels_ServerSocketChannel$object;
struct _jc_java_nio_channels_SocketChannel$object;
struct _jc_java_nio_channels_spi_AbstractSelector$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_java_nio_channels_spi_SelectorProvider$sub_refs	_jc_java_nio_channels_spi_SelectorProvider$sub_refs;
typedef struct _jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs	_jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs;
typedef struct _jc_java_nio_channels_spi_SelectorProvider$refs	_jc_java_nio_channels_spi_SelectorProvider$refs;
typedef struct _jc_java_nio_channels_spi_SelectorProvider$nonrefs	_jc_java_nio_channels_spi_SelectorProvider$nonrefs;
typedef struct _jc_java_nio_channels_spi_SelectorProvider$object	_jc_java_nio_channels_spi_SelectorProvider$object;

typedef struct _jc_java_nio_channels_spi_SelectorProvider$fields_struct	_jc_java_nio_channels_spi_SelectorProvider$fields_struct;
typedef const struct _jc_java_nio_channels_spi_SelectorProvider$vmethods	_jc_java_nio_channels_spi_SelectorProvider$vmethods;
typedef const struct _jc_java_nio_channels_spi_SelectorProvider$vtable	_jc_java_nio_channels_spi_SelectorProvider$vtable;
typedef const struct _jc_java_nio_channels_spi_SelectorProvider$vtype	_jc_java_nio_channels_spi_SelectorProvider$vtype;

// Class fields structure
struct _jc_java_nio_channels_spi_SelectorProvider$fields_struct {
	struct _jc_java_nio_channels_spi_SelectorProvider$object	*systemDefaultProvider;
};
extern _jc_java_nio_channels_spi_SelectorProvider$fields_struct _jc_java_nio_channels_spi_SelectorProvider$class_fields;

// Constructors
extern void _jc_java_nio_channels_spi_SelectorProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);

// Virtual methods
extern struct _jc_java_nio_channels_DatagramChannel$object *_jc_java_nio_channels_spi_SelectorProvider$method$openDatagramChannel$ab5cdc178ebfdf11(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);
extern struct _jc_java_nio_channels_Pipe$object *_jc_java_nio_channels_spi_SelectorProvider$method$openPipe$a14c1306bc23b331(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);
extern struct _jc_java_nio_channels_spi_AbstractSelector$object *_jc_java_nio_channels_spi_SelectorProvider$method$openSelector$bb7aeaf99dc269ad(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);
extern struct _jc_java_nio_channels_ServerSocketChannel$object *_jc_java_nio_channels_spi_SelectorProvider$method$openServerSocketChannel$c5bb130c60378b57(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_java_nio_channels_spi_SelectorProvider$method$openSocketChannel$24c1128adb909d51(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openDatagramChannel$ab5cdc178ebfdf11;
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openPipe$a14c1306bc23b331;
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openSelector$bb7aeaf99dc269ad;
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openServerSocketChannel$c5bb130c60378b57;
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openSocketChannel$24c1128adb909d51;

// Static methods
extern struct _jc_java_nio_channels_spi_SelectorProvider$object *_jc_java_nio_channels_spi_SelectorProvider$method$provider$f1e7ffe0eaeee1b8(_jc_env *);

// Virtual methods structure
struct _jc_java_nio_channels_spi_SelectorProvider$vmethods {
	struct _jc_java_nio_channels_DatagramChannel$object	*(*openDatagramChannel$ab5cdc178ebfdf11)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);
	struct _jc_java_nio_channels_Pipe$object	*(*openPipe$a14c1306bc23b331)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);
	struct _jc_java_nio_channels_spi_AbstractSelector$object	*(*openSelector$bb7aeaf99dc269ad)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);
	struct _jc_java_nio_channels_ServerSocketChannel$object	*(*openServerSocketChannel$c5bb130c60378b57)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);
	struct _jc_java_nio_channels_SocketChannel$object	*(*openSocketChannel$24c1128adb909d51)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);
};

// Vtable
struct _jc_java_nio_channels_spi_SelectorProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_SelectorProvider$vmethods	java_nio_channels_spi_SelectorProvider;
};

// Vtype
struct _jc_java_nio_channels_spi_SelectorProvider$vtype {
	_jc_type			type;
	_jc_java_nio_channels_spi_SelectorProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_spi_SelectorProvider$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_spi_SelectorProvider$refs {
    _jc_java_nio_channels_spi_SelectorProvider$sub_refs	java_nio_channels_spi_SelectorProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_spi_SelectorProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs	java_nio_channels_spi_SelectorProvider;
};

// Object instance structure
struct _jc_java_nio_channels_spi_SelectorProvider$object {
	_jc_java_nio_channels_spi_SelectorProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_spi_SelectorProvider$vtype	*vtype;
	_jc_java_nio_channels_spi_SelectorProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_spi_SelectorProvider$vtype _jc_java_nio_channels_spi_SelectorProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_spi_SelectorProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_spi_SelectorProvider$class_object;

#endif	/* _JC_java_nio_channels_spi_SelectorProvider_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/spi/SelectorProvider.h <==
// public abstract class java.nio.channels.spi.SelectorProvider

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7a7cc23db1b62549 java_nio_channels_spi_SelectorProvider

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_channels_spi_SelectorProvider_H_
#define _JC_java_nio_channels_spi_SelectorProvider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_DatagramChannel$object;
struct _jc_java_nio_channels_Pipe$object;
struct _jc_java_nio_channels_ServerSocketChannel$object;
struct _jc_java_nio_channels_SocketChannel$object;
struct _jc_java_nio_channels_spi_AbstractSelector$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_java_nio_channels_spi_SelectorProvider$sub_refs	_jc_java_nio_channels_spi_SelectorProvider$sub_refs;
typedef struct _jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs	_jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs;
typedef struct _jc_java_nio_channels_spi_SelectorProvider$refs	_jc_java_nio_channels_spi_SelectorProvider$refs;
typedef struct _jc_java_nio_channels_spi_SelectorProvider$nonrefs	_jc_java_nio_channels_spi_SelectorProvider$nonrefs;
typedef struct _jc_java_nio_channels_spi_SelectorProvider$object	_jc_java_nio_channels_spi_SelectorProvider$object;

typedef struct _jc_java_nio_channels_spi_SelectorProvider$fields_struct	_jc_java_nio_channels_spi_SelectorProvider$fields_struct;
typedef const struct _jc_java_nio_channels_spi_SelectorProvider$vmethods	_jc_java_nio_channels_spi_SelectorProvider$vmethods;
typedef const struct _jc_java_nio_channels_spi_SelectorProvider$vtable	_jc_java_nio_channels_spi_SelectorProvider$vtable;
typedef const struct _jc_java_nio_channels_spi_SelectorProvider$vtype	_jc_java_nio_channels_spi_SelectorProvider$vtype;

// Class fields structure
struct _jc_java_nio_channels_spi_SelectorProvider$fields_struct {
	struct _jc_java_nio_channels_spi_SelectorProvider$object	*systemDefaultProvider;
};
extern _jc_java_nio_channels_spi_SelectorProvider$fields_struct _jc_java_nio_channels_spi_SelectorProvider$class_fields;

// Constructors
extern void _jc_java_nio_channels_spi_SelectorProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_channels_DatagramChannel$object *_jc_java_nio_channels_spi_SelectorProvider$method$openDatagramChannel$ab5cdc178ebfdf11(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_Pipe$object *_jc_java_nio_channels_spi_SelectorProvider$method$openPipe$a14c1306bc23b331(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_spi_AbstractSelector$object *_jc_java_nio_channels_spi_SelectorProvider$method$openSelector$bb7aeaf99dc269ad(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_ServerSocketChannel$object *_jc_java_nio_channels_spi_SelectorProvider$method$openServerSocketChannel$c5bb130c60378b57(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_channels_SocketChannel$object *_jc_java_nio_channels_spi_SelectorProvider$method$openSocketChannel$24c1128adb909d51(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openDatagramChannel$ab5cdc178ebfdf11;
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openPipe$a14c1306bc23b331;
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openSelector$bb7aeaf99dc269ad;
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openServerSocketChannel$c5bb130c60378b57;
extern _jc_method _jc_java_nio_channels_spi_SelectorProvider$method_info$openSocketChannel$24c1128adb909d51;

// Static methods
extern struct _jc_java_nio_channels_spi_SelectorProvider$object *_jc_java_nio_channels_spi_SelectorProvider$method$provider$f1e7ffe0eaeee1b8(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_spi_SelectorProvider$vmethods {
	struct _jc_java_nio_channels_DatagramChannel$object	*(*openDatagramChannel$ab5cdc178ebfdf11)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_Pipe$object	*(*openPipe$a14c1306bc23b331)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_spi_AbstractSelector$object	*(*openSelector$bb7aeaf99dc269ad)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_ServerSocketChannel$object	*(*openServerSocketChannel$c5bb130c60378b57)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_channels_SocketChannel$object	*(*openSocketChannel$24c1128adb909d51)(_jc_env *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_channels_spi_SelectorProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_SelectorProvider$vmethods	java_nio_channels_spi_SelectorProvider;
};

// Vtype
struct _jc_java_nio_channels_spi_SelectorProvider$vtype {
	_jc_type			type;
	_jc_java_nio_channels_spi_SelectorProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_spi_SelectorProvider$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_spi_SelectorProvider$refs {
    _jc_java_nio_channels_spi_SelectorProvider$sub_refs	java_nio_channels_spi_SelectorProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_spi_SelectorProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_SelectorProvider$sub_nonrefs	java_nio_channels_spi_SelectorProvider;
};

// Object instance structure
struct _jc_java_nio_channels_spi_SelectorProvider$object {
	_jc_java_nio_channels_spi_SelectorProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_spi_SelectorProvider$vtype	*vtype;
	_jc_java_nio_channels_spi_SelectorProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_spi_SelectorProvider$vtype _jc_java_nio_channels_spi_SelectorProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_spi_SelectorProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_spi_SelectorProvider$class_object;

#endif	/* _JC_java_nio_channels_spi_SelectorProvider_H_ */
